==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/bas-CM.pl <==
{
  am_pm_abbreviated => [
    "I bik\N{U+025b}\N{U+0302}gl\N{U+00e0}",
    "I \N{U+0253}ugaj\N{U+0254}p",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "bas-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "nja",
    "uum",
    "\N{U+014b}ge",
    "mb\N{U+0254}",
    "k\N{U+0254}\N{U+0254}",
    "jon",
    "n\N{U+0254}y",
  ],
  day_format_narrow => [
    "n",
    "u",
    "\N{U+014b}",
    "m",
    "k",
    "j",
    "n",
  ],
  day_format_wide => [
    "\N{U+014b}gw\N{U+00e0} nja\N{U+014b}gumba",
    "\N{U+014b}gw\N{U+00e0} \N{U+00fb}m",
    "\N{U+014b}gw\N{U+00e0} \N{U+014b}g\N{U+00ea}",
    "\N{U+014b}gw\N{U+00e0} mb\N{U+0254}k",
    "\N{U+014b}gw\N{U+00e0} k\N{U+0254}\N{U+0254}",
    "\N{U+014b}gw\N{U+00e0} j\N{U+00f4}n",
    "\N{U+014b}gw\N{U+00e0} n\N{U+0254}\N{U+0302}y",
  ],
  day_stand_alone_abbreviated => [
    "nja",
    "uum",
    "\N{U+014b}ge",
    "mb\N{U+0254}",
    "k\N{U+0254}\N{U+0254}",
    "jon",
    "n\N{U+0254}y",
  ],
  day_stand_alone_narrow => [
    "n",
    "u",
    "\N{U+014b}",
    "m",
    "k",
    "j",
    "n",
  ],
  day_stand_alone_wide => [
    "\N{U+014b}gw\N{U+00e0} nja\N{U+014b}gumba",
    "\N{U+014b}gw\N{U+00e0} \N{U+00fb}m",
    "\N{U+014b}gw\N{U+00e0} \N{U+014b}g\N{U+00ea}",
    "\N{U+014b}gw\N{U+00e0} mb\N{U+0254}k",
    "\N{U+014b}gw\N{U+00e0} k\N{U+0254}\N{U+0254}",
    "\N{U+014b}gw\N{U+00e0} j\N{U+00f4}n",
    "\N{U+014b}gw\N{U+00e0} n\N{U+0254}\N{U+0302}y",
  ],
  era_abbreviated => [
    "b.Y.K",
    "m.Y.K",
  ],
  era_narrow => [
    "b.Y.K",
    "m.Y.K",
  ],
  era_wide => [
    "bis\N{U+016b} bi Yes\N{U+00f9} Kr\N{U+01d0}st\N{U+00f2}",
    "i mb\N{U+016b}s Yes\N{U+00f9} Kr\N{U+01d0}st\N{U+00f2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Basaa",
  month_format_abbreviated => [
    "k\N{U+0254}n",
    "mac",
    "mat",
    "mto",
    "mpu",
    "hil",
    "nje",
    "hik",
    "dip",
    "bio",
    "may",
    "li\N{U+0253}",
  ],
  month_format_narrow => [
    "k",
    "m",
    "m",
    "m",
    "m",
    "h",
    "n",
    "h",
    "d",
    "b",
    "m",
    "l",
  ],
  month_format_wide => [
    "K\N{U+0254}nd\N{U+0254}\N{U+014b}",
    "M\N{U+00e0}c\N{U+025b}\N{U+0302}l",
    "M\N{U+00e0}t\N{U+00f9}mb",
    "M\N{U+00e0}top",
    "M\N{U+0300}puy\N{U+025b}",
    "H\N{U+00ec}l\N{U+00f2}nd\N{U+025b}\N{U+0300}",
    "Nj\N{U+00e8}b\N{U+00e0}",
    "H\N{U+00ec}ka\N{U+014b}",
    "D\N{U+00ec}p\N{U+0254}\N{U+0300}s",
    "B\N{U+00ec}\N{U+00f2}\N{U+00f4}m",
    "M\N{U+00e0}y\N{U+025b}s\N{U+00e8}p",
    "L\N{U+00ec}buy li \N{U+0144}y\N{U+00e8}e",
  ],
  month_stand_alone_abbreviated => [
    "k\N{U+0254}n",
    "mac",
    "mat",
    "mto",
    "mpu",
    "hil",
    "nje",
    "hik",
    "dip",
    "bio",
    "may",
    "li\N{U+0253}",
  ],
  month_stand_alone_narrow => [
    "k",
    "m",
    "m",
    "m",
    "m",
    "h",
    "n",
    "h",
    "d",
    "b",
    "m",
    "l",
  ],
  month_stand_alone_wide => [
    "K\N{U+0254}nd\N{U+0254}\N{U+014b}",
    "M\N{U+00e0}c\N{U+025b}\N{U+0302}l",
    "M\N{U+00e0}t\N{U+00f9}mb",
    "M\N{U+00e0}top",
    "M\N{U+0300}puy\N{U+025b}",
    "H\N{U+00ec}l\N{U+00f2}nd\N{U+025b}\N{U+0300}",
    "Nj\N{U+00e8}b\N{U+00e0}",
    "H\N{U+00ec}ka\N{U+014b}",
    "D\N{U+00ec}p\N{U+0254}\N{U+0300}s",
    "B\N{U+00ec}\N{U+00f2}\N{U+00f4}m",
    "M\N{U+00e0}y\N{U+025b}s\N{U+00e8}p",
    "L\N{U+00ec}buy li \N{U+0144}y\N{U+00e8}e",
  ],
  name => "Basaa Cameroon",
  native_language => "\N{U+0181}\N{U+00e0}s\N{U+00e0}a",
  native_name => "\N{U+0181}\N{U+00e0}s\N{U+00e0}a K\N{U+00e0}m\N{U+025b}\N{U+0300}r\N{U+00fb}n",
  native_script => undef,
  native_territory => "K\N{U+00e0}m\N{U+025b}\N{U+0300}r\N{U+00fb}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1s3",
    "K2s3",
    "K3s3",
    "K4s3",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "K\N{U+00e8}k bisu i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bi\N{U+0253}a\N{U+00e0} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bia\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bin\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
  ],
  quarter_stand_alone_abbreviated => [
    "K1s3",
    "K2s3",
    "K3s3",
    "K4s3",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "K\N{U+00e8}k bisu i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bi\N{U+0253}a\N{U+00e0} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bia\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bin\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.41.orig.tar.gz: DateTime-Locale-1.41/share/bas-CM.pl <==
{
  am_pm_abbreviated => [
    "I\N{U+202f}bik\N{U+025b}\N{U+0302}gl\N{U+00e0}",
    "I\N{U+202f}\N{U+0253}ugaj\N{U+0254}p",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "bas-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "nja",
    "uum",
    "\N{U+014b}ge",
    "mb\N{U+0254}",
    "k\N{U+0254}\N{U+0254}",
    "jon",
    "n\N{U+0254}y",
  ],
  day_format_narrow => [
    "n",
    "u",
    "\N{U+014b}",
    "m",
    "k",
    "j",
    "n",
  ],
  day_format_wide => [
    "\N{U+014b}gw\N{U+00e0} nja\N{U+014b}gumba",
    "\N{U+014b}gw\N{U+00e0} \N{U+00fb}m",
    "\N{U+014b}gw\N{U+00e0} \N{U+014b}g\N{U+00ea}",
    "\N{U+014b}gw\N{U+00e0} mb\N{U+0254}k",
    "\N{U+014b}gw\N{U+00e0} k\N{U+0254}\N{U+0254}",
    "\N{U+014b}gw\N{U+00e0} j\N{U+00f4}n",
    "\N{U+014b}gw\N{U+00e0} n\N{U+0254}\N{U+0302}y",
  ],
  day_stand_alone_abbreviated => [
    "nja",
    "uum",
    "\N{U+014b}ge",
    "mb\N{U+0254}",
    "k\N{U+0254}\N{U+0254}",
    "jon",
    "n\N{U+0254}y",
  ],
  day_stand_alone_narrow => [
    "n",
    "u",
    "\N{U+014b}",
    "m",
    "k",
    "j",
    "n",
  ],
  day_stand_alone_wide => [
    "\N{U+014b}gw\N{U+00e0} nja\N{U+014b}gumba",
    "\N{U+014b}gw\N{U+00e0} \N{U+00fb}m",
    "\N{U+014b}gw\N{U+00e0} \N{U+014b}g\N{U+00ea}",
    "\N{U+014b}gw\N{U+00e0} mb\N{U+0254}k",
    "\N{U+014b}gw\N{U+00e0} k\N{U+0254}\N{U+0254}",
    "\N{U+014b}gw\N{U+00e0} j\N{U+00f4}n",
    "\N{U+014b}gw\N{U+00e0} n\N{U+0254}\N{U+0302}y",
  ],
  era_abbreviated => [
    "b.Y.K",
    "m.Y.K",
  ],
  era_narrow => [
    "b.Y.K",
    "m.Y.K",
  ],
  era_wide => [
    "bis\N{U+016b} bi Yes\N{U+00f9} Kr\N{U+01d0}st\N{U+00f2}",
    "i mb\N{U+016b}s Yes\N{U+00f9} Kr\N{U+01d0}st\N{U+00f2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Basaa",
  month_format_abbreviated => [
    "k\N{U+0254}n",
    "mac",
    "mat",
    "mto",
    "mpu",
    "hil",
    "nje",
    "hik",
    "dip",
    "bio",
    "may",
    "li\N{U+0253}",
  ],
  month_format_narrow => [
    "k",
    "m",
    "m",
    "m",
    "m",
    "h",
    "n",
    "h",
    "d",
    "b",
    "m",
    "l",
  ],
  month_format_wide => [
    "K\N{U+0254}nd\N{U+0254}\N{U+014b}",
    "M\N{U+00e0}c\N{U+025b}\N{U+0302}l",
    "M\N{U+00e0}t\N{U+00f9}mb",
    "M\N{U+00e0}top",
    "M\N{U+0300}puy\N{U+025b}",
    "H\N{U+00ec}l\N{U+00f2}nd\N{U+025b}\N{U+0300}",
    "Nj\N{U+00e8}b\N{U+00e0}",
    "H\N{U+00ec}ka\N{U+014b}",
    "D\N{U+00ec}p\N{U+0254}\N{U+0300}s",
    "B\N{U+00ec}\N{U+00f2}\N{U+00f4}m",
    "M\N{U+00e0}y\N{U+025b}s\N{U+00e8}p",
    "L\N{U+00ec}buy li \N{U+0144}y\N{U+00e8}e",
  ],
  month_stand_alone_abbreviated => [
    "k\N{U+0254}n",
    "mac",
    "mat",
    "mto",
    "mpu",
    "hil",
    "nje",
    "hik",
    "dip",
    "bio",
    "may",
    "li\N{U+0253}",
  ],
  month_stand_alone_narrow => [
    "k",
    "m",
    "m",
    "m",
    "m",
    "h",
    "n",
    "h",
    "d",
    "b",
    "m",
    "l",
  ],
  month_stand_alone_wide => [
    "K\N{U+0254}nd\N{U+0254}\N{U+014b}",
    "M\N{U+00e0}c\N{U+025b}\N{U+0302}l",
    "M\N{U+00e0}t\N{U+00f9}mb",
    "M\N{U+00e0}top",
    "M\N{U+0300}puy\N{U+025b}",
    "H\N{U+00ec}l\N{U+00f2}nd\N{U+025b}\N{U+0300}",
    "Nj\N{U+00e8}b\N{U+00e0}",
    "H\N{U+00ec}ka\N{U+014b}",
    "D\N{U+00ec}p\N{U+0254}\N{U+0300}s",
    "B\N{U+00ec}\N{U+00f2}\N{U+00f4}m",
    "M\N{U+00e0}y\N{U+025b}s\N{U+00e8}p",
    "L\N{U+00ec}buy li \N{U+0144}y\N{U+00e8}e",
  ],
  name => "Basaa Cameroon",
  native_language => "\N{U+0181}\N{U+00e0}s\N{U+00e0}a",
  native_name => "\N{U+0181}\N{U+00e0}s\N{U+00e0}a K\N{U+00e0}m\N{U+025b}\N{U+0300}r\N{U+00fb}n",
  native_script => undef,
  native_territory => "K\N{U+00e0}m\N{U+025b}\N{U+0300}r\N{U+00fb}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1s3",
    "K2s3",
    "K3s3",
    "K4s3",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "K\N{U+00e8}k bisu i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bi\N{U+0253}a\N{U+00e0} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bia\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bin\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
  ],
  quarter_stand_alone_abbreviated => [
    "K1s3",
    "K2s3",
    "K3s3",
    "K4s3",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "K\N{U+00e8}k bisu i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bi\N{U+0253}a\N{U+00e0} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bia\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
    "K\N{U+00e8}k i \N{U+0144}yonos bin\N{U+00e2} i so\N{U+014b} ia\N{U+00e2}",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
